<?php
	function persian_num($number, $do_format = FALSE)
	{

		// Numbers conversion map
		$num_covmap = array(
			
			'0' => chr(0xDB) . chr(0xB0),	// Zero (U+06F0)
			    chr(0xDB) . chr(0xB1),	// One (U+06F1)
			    chr(0xDB) . chr(0xB2),	// Two (U+06F2)
			    chr(0xDB) . chr(0xB3),	// Three (U+06F3)
			    chr(0xDB) . chr(0xB4),	// Four (U+06F4)
			    chr(0xDB) . chr(0xB5),	// Five (U+06F5)
			    chr(0xDB) . chr(0xB6),	// Six (U+06F6)
			    chr(0xDB) . chr(0xB7),	// Seven (U+06F7)
			    chr(0xDB) . chr(0xB8),	// Eight (U+06F8)
			    chr(0xDB) . chr(0xB9),	// Nine (U+06F9)
		);			

		$th_separator = chr(0xD9) . chr(0xAC);	// ARABIC THOUSANDS SEPARATOR (U+066C)

		if ($do_format) {
			// Add comma (",") between every group of thousands
			$number = number_format($number);
		}

		// Replace Latin symbols with Persian
		$number = strtr($number, $num_covmap);

		if ($do_format) {
			// Replace comma (",") with U+066C (as is used in Persian to separate thousands)
			$number = str_replace(',', $th_separator, $number);
		}

		return $number;
	}
	
	function div($a,$b) {
		return (int) ($a / $b);
	}
	
	function gregorian_to_jalali ($g_y, $g_m, $g_d)
	{
		$g_days_in_month = array(31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
		$j_days_in_month = array(31, 31, 31, 31, 31, 31, 30, 30, 30, 30, 30, 29);
	
	   $gy = $g_y-1600;
	   $gm = $g_m-1;
	   $gd = $g_d-1;
	
	   $g_day_no = 365*$gy+div($gy+3,4)-div($gy+99,100)+div($gy+399,400);
	
	   for ($i=0; $i < $gm; ++$i)
		  $g_day_no += $g_days_in_month[$i];
	   if ($gm>1 && (($gy%4==0 && $gy%100!=0) || ($gy%400==0)))
		  /* leap and after Feb */
		  $g_day_no++;
	   $g_day_no += $gd;
	
	   $j_day_no = $g_day_no-79;
	
	   $j_np = div($j_day_no, 12053); /* 12053 = 365*33 + 32/4 */
	   $j_day_no = $j_day_no % 12053;
	
	   $jy = 979+33*$j_np+4*div($j_day_no,1461); /* 1461 = 365*4 + 4/4 */
	
	   $j_day_no %= 1461;
	
	   if ($j_day_no >= 366) {
		  $jy += div($j_day_no-1, 365);
		  $j_day_no = ($j_day_no-1)%365;
	   }
	
	   for ($i = 0; $i < 11 && $j_day_no >= $j_days_in_month[$i]; ++$i)
		  $j_day_no -= $j_days_in_month[$i];
	   $jm = $i+1;
	   $jd = $j_day_no+1;
	
	   return array($jy, $jm, $jd);
	}
	
	function jalali_to_gregorian($j_y, $j_m, $j_d)
	{
		$g_days_in_month = array(31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
		$j_days_in_month = array(31, 31, 31, 31, 31, 31, 30, 30, 30, 30, 30, 29);
	
	   $jy = $j_y-979;
	   $jm = $j_m-1;
	   $jd = $j_d-1;
	
	   $j_day_no = 365*$jy + div($jy, 33)*8 + div($jy%33+3, 4);
	   for ($i=0; $i < $jm; ++$i)
		  $j_day_no += $j_days_in_month[$i];
	
	   $j_day_no += $jd;
	
	   $g_day_no = $j_day_no+79;
	
	   $gy = 1600 + 400*div($g_day_no, 146097); /* 146097 = 365*400 + 400/4 - 400/100 + 400/400 */
	   $g_day_no = $g_day_no % 146097;
	
	   $leap = true;
	   if ($g_day_no >= 36525) /* 36525 = 365*100 + 100/4 */
	   {
		  $g_day_no--;
		  $gy += 100*div($g_day_no,  36524); /* 36524 = 365*100 + 100/4 - 100/100 */
		  $g_day_no = $g_day_no % 36524;
	
		  if ($g_day_no >= 365)
			 $g_day_no++;
		  else
			 $leap = false;
	   }
	
	   $gy += 4*div($g_day_no, 1461); /* 1461 = 365*4 + 4/4 */
	   $g_day_no %= 1461;
	
	   if ($g_day_no >= 366) {
		  $leap = false;
	
		  $g_day_no--;
		  $gy += div($g_day_no, 365);
		  $g_day_no = $g_day_no % 365;
	   }
	
	   for ($i = 0; $g_day_no >= $g_days_in_month[$i] + ($i == 1 && $leap); $i++)
		  $g_day_no -= $g_days_in_month[$i] + ($i == 1 && $leap);
	   $gm = $i+1;
	   $gd = $g_day_no+1;
	
	   return ($gy.'-'.$gm.'-'.$gd);
	}
	
	function mija($daj){
	   list($gyear, $gmonth, $gday ) = preg_split ('/-/', $daj);
	list( $jyear, $jmonth, $jday ) = gregorian_to_jalali($gyear, $gmonth, $gday);
	
	if ($jmonth < 10  and $jday < 10 ){
	
	$jdate = $jyear."/".'0'.$jmonth."/".'0'.$jday;
	}
	if ($jmonth < 10  and $jday >= 10 ){
	
	$jdate = $jyear."/".'0'.$jmonth."/".$jday;
	}
	if ($jmonth >= 10  and $jday < 10 ){
	
	$jdate = $jyear."/".$jmonth."/".'0'.$jday;
	}
	
	if ($jmonth >= 10  and $jday >= 10 ){
	
	$jdate = $jyear."/".$jmonth."/".$jday;
	}
	return $jdate;
	
	}
	function jami($dam){
	   list($gyear, $gmonth, $gday ) = preg_split ('-/-', $dam);
	list( $jyear, $jmonth, $jday ) = jalali_to_gregorian($gyear, $gmonth, $gday);
	
	if ($jmonth < 10  and $jday < 10 ){
	
	$mdate = $jyear."/".'0'.$jmonth."/".'0'.$jday;
	}
	if ($jmonth < 10  and $jday >= 10 ){
	
	$mdate = $jyear."/".'0'.$jmonth."/".$jday;
	}
	if ($jmonth >= 10  and $jday < 10 ){
	
	$mdate = $jyear."/".$jmonth."/".'0'.$jday;
	}
	
	if ($jmonth >= 10  and $jday >= 10 ){
	
	$mdate = $jyear."/".$jmonth."/".$jday;
	}
	return $mdate;
	
	}
	
	
/*************************** ghamari ***********************************/	

$date=date('Y-m-d');
$date=explode('-',$date);
$date=gregorian_to_jalali($date[0],$date[1],$date[2]);
define(DATE,implode('-',$date));


function my_date($day,$opearate)
{
	if($opearate=="-")
	{
		$date = time() - ($day*24*60*60);
	}
	else
	{
		$date = time() + ($day*24*60*60);		
	}
	$date=date('Y-m-d',$date);
	return $date;	
}

function date_sh($date)
{
	$date=explode('-',$date);
	$date=gregorian_to_jalali($date[0],$date[1],$date[2]);
	return implode('/',$date);	
}

function date_mi($date)
{
	$date=explode('/',$date);
	$date=jalali_to_gregorian($date[0],$date[1],$date[2]);
	return implode('-',$date);	
	
}

/*************************** ghamari END***********************************/	

function exp_number($string)
{
	$count=strlen($string);
	$string=(string) $string;
	$j=0;
	for($i=strlen($string);$i>=0;$i--)
	{
		
		$output=$string[$i].$output;
	
		if(($j % 3==0) && ($count!=$i) && ($i!=0))	
		{

			$output=','.$output;
		}	
		$j++;
	}
	

	return $output;

}
?>